diff --git a/README.md b/README.md
index a5d80e60162..0d295d7e9c4 100644
--- a/README.md
+++ b/README.md
@@ -9,7 +9,7 @@
This project contains compontents which implements common functionalities used in WSO2 analytics platform.
-#### Carbon Analytics repo contains components realted to WSO2 Stream Processor such as:
+#### Carbon Analytics repo contains components realted to WSO2 Streaming Integrator such as:
* stream-processing
* editor
diff --git a/components/org.wso2.carbon.analytics.auth.rest.api/pom.xml b/components/org.wso2.carbon.analytics.auth.rest.api/pom.xml
index f72e89fbe5e..ea60a9c4c84 100644
--- a/components/org.wso2.carbon.analytics.auth.rest.api/pom.xml
+++ b/components/org.wso2.carbon.analytics.auth.rest.api/pom.xml
@@ -26,7 +26,7 @@
org.wso2.carbon.analytics.auth.rest.apibundle
- WSO2 Stream Processor - Authentication API
+ WSO2 Streaming Integrator - Authentication APIhttp://maven.apache.org
diff --git a/components/org.wso2.carbon.analytics.auth.rest.api/src/gen/java/org/wso2/carbon/analytics/auth/rest/api/LoginApi.java b/components/org.wso2.carbon.analytics.auth.rest.api/src/gen/java/org/wso2/carbon/analytics/auth/rest/api/LoginApi.java
index 0d401d1b197..1cc97371992 100644
--- a/components/org.wso2.carbon.analytics.auth.rest.api/src/gen/java/org/wso2/carbon/analytics/auth/rest/api/LoginApi.java
+++ b/components/org.wso2.carbon.analytics.auth.rest.api/src/gen/java/org/wso2/carbon/analytics/auth/rest/api/LoginApi.java
@@ -56,7 +56,7 @@ public class LoginApi implements Microservice {
@Path("/{appName:(.*)}")
@Consumes({"application/x-www-form-urlencoded", "multipart/form-data"})
@Produces({"application/json"})
- @io.swagger.annotations.ApiOperation(value = "", notes = "Login Request to Stream Processor.",
+ @io.swagger.annotations.ApiOperation(value = "", notes = "Login Request to Streaming Integrator.",
response = UserDTO.class, tags = {})
@io.swagger.annotations.ApiResponses(value = {
@io.swagger.annotations.ApiResponse(code = 200, message = "Authorization Request Successful.",
@@ -108,7 +108,7 @@ public Response loginCallbackAppNameGet(@ApiParam(value = "AppName", required =
@GET
@Path("/auth-type")
- @io.swagger.annotations.ApiOperation(value = "", notes = "Login type check Request to Stream Processor.",
+ @io.swagger.annotations.ApiOperation(value = "", notes = "Login type check Request to Streaming Integrator.",
response = UserDTO.class, tags = {})
@io.swagger.annotations.ApiResponses(value = {
@io.swagger.annotations.ApiResponse(code = 200, message = "Type Check Request Successful.",
diff --git a/components/org.wso2.carbon.analytics.auth.rest.api/src/gen/java/org/wso2/carbon/analytics/auth/rest/api/LogoutApi.java b/components/org.wso2.carbon.analytics.auth.rest.api/src/gen/java/org/wso2/carbon/analytics/auth/rest/api/LogoutApi.java
index f5ac8c0463a..c770070605d 100644
--- a/components/org.wso2.carbon.analytics.auth.rest.api/src/gen/java/org/wso2/carbon/analytics/auth/rest/api/LogoutApi.java
+++ b/components/org.wso2.carbon.analytics.auth.rest.api/src/gen/java/org/wso2/carbon/analytics/auth/rest/api/LogoutApi.java
@@ -55,7 +55,7 @@ public class LogoutApi implements Microservice {
@Path("/{appName:(.*)}")
@Consumes({"application/json"})
@Produces({"application/json"})
- @io.swagger.annotations.ApiOperation(value = "", notes = "Logout Request to Stream Processor",
+ @io.swagger.annotations.ApiOperation(value = "", notes = "Logout Request to Streaming Integrator",
response = void.class, tags = {})
@io.swagger.annotations.ApiResponses(value = {
@io.swagger.annotations.ApiResponse(code = 200, message = "Authorization Request Successful.",
@@ -72,7 +72,7 @@ public Response logoutAppNamePost(@ApiParam(value = "AppName", required = true)
@GET
@Path("/slo/{appName}")
@Produces({"application/json"})
- @io.swagger.annotations.ApiOperation(value = "", notes = "Login type check Request to Stream Processor.",
+ @io.swagger.annotations.ApiOperation(value = "", notes = "Login type check Request to Streaming Integrator.",
response = HashMap.class, tags = {})
@io.swagger.annotations.ApiResponses(value = {
@io.swagger.annotations.ApiResponse(code = 200, message = "SSO logout Request to Stream processor",
diff --git a/components/org.wso2.carbon.analytics.auth.rest.api/src/main/resources/authenticator-api.yaml b/components/org.wso2.carbon.analytics.auth.rest.api/src/main/resources/authenticator-api.yaml
index c8adea849a6..bc846b0dc22 100644
--- a/components/org.wso2.carbon.analytics.auth.rest.api/src/main/resources/authenticator-api.yaml
+++ b/components/org.wso2.carbon.analytics.auth.rest.api/src/main/resources/authenticator-api.yaml
@@ -1,8 +1,8 @@
swagger: '2.0'
info:
version: 1.0.0
- title: Stream Processor Authentication Service
- description: This provides service to authenticate users in Stream Processor
+ title: Streaming Integrator Authentication Service
+ description: This provides service to authenticate users in Streaming Integrator
contact:
name: WSO2
url: 'http://wso2.com/smart-analytics'
@@ -22,7 +22,7 @@ paths:
/login/{appName}:
post:
description:
- Login Request to Stream Processor.
+ Login Request to Streaming Integrator.
consumes:
- application/x-www-form-urlencoded
- multipart/form-data
@@ -92,7 +92,7 @@ paths:
/logout/{appName}:
post:
description:
- Logout Request to Stream Processor
+ Logout Request to Streaming Integrator
parameters:
- name: appName
in: path
diff --git a/components/org.wso2.carbon.analytics.msf4j.interceptor.common/pom.xml b/components/org.wso2.carbon.analytics.msf4j.interceptor.common/pom.xml
index fa57378aa69..050020c1e6e 100644
--- a/components/org.wso2.carbon.analytics.msf4j.interceptor.common/pom.xml
+++ b/components/org.wso2.carbon.analytics.msf4j.interceptor.common/pom.xml
@@ -28,7 +28,7 @@
org.wso2.carbon.analytics.msf4j.interceptor.commonbundle
- WSO2 Stream Processor - Interceptors
+ WSO2 Streaming Integrator - Interceptorshttp://maven.apache.org
diff --git a/components/org.wso2.carbon.business.rules.core/pom.xml b/components/org.wso2.carbon.business.rules.core/pom.xml
index 76fe6def732..948eb947193 100644
--- a/components/org.wso2.carbon.business.rules.core/pom.xml
+++ b/components/org.wso2.carbon.business.rules.core/pom.xml
@@ -29,7 +29,7 @@
org.wso2.carbon.business.rules.corebundle
- WSO2 Stream Processor - Business Rules
+ WSO2 Streaming Integrator - Business Ruleshttp://wso2.org
diff --git a/components/org.wso2.carbon.business.rules.templates.editor.core/package.json b/components/org.wso2.carbon.business.rules.templates.editor.core/package.json
index db5f5811a45..830125ed833 100644
--- a/components/org.wso2.carbon.business.rules.templates.editor.core/package.json
+++ b/components/org.wso2.carbon.business.rules.templates.editor.core/package.json
@@ -25,7 +25,7 @@
"react-router-dom": "^4.2.2",
"react-scripts": "1.0.11",
"react-tap-event-plugin": "^2.0.1",
- "rimraf": "^2.6.3",
+ "rimraf": "^2.7.1",
"typeface-roboto": "0.0.35"
},
"devDependencies": {
diff --git a/components/org.wso2.carbon.business.rules.templates.editor.core/pom.xml b/components/org.wso2.carbon.business.rules.templates.editor.core/pom.xml
index 8bf125ee0b2..d9a1b7622d3 100644
--- a/components/org.wso2.carbon.business.rules.templates.editor.core/pom.xml
+++ b/components/org.wso2.carbon.business.rules.templates.editor.core/pom.xml
@@ -29,7 +29,7 @@
org.wso2.carbon.business.rules.templates.editor.corebundle
- WSO2 Stream Processor - Business Rules Template Editor
+ WSO2 Streaming Integrator - Business Rules Template Editorhttp://wso2.org
diff --git a/components/org.wso2.carbon.business.rules.web/package.json b/components/org.wso2.carbon.business.rules.web/package.json
index e5fc41fd7cd..bce9fc5e2a4 100644
--- a/components/org.wso2.carbon.business.rules.web/package.json
+++ b/components/org.wso2.carbon.business.rules.web/package.json
@@ -20,7 +20,7 @@
"react-router-dom": "^4.2.2",
"react-scripts": "1.0.11",
"react-tap-event-plugin": "^2.0.1",
- "rimraf": "^2.6.3",
+ "rimraf": "^2.7.1",
"typeface-roboto": "0.0.35"
},
"devDependencies": {
diff --git a/components/org.wso2.carbon.event.simulator.core/pom.xml b/components/org.wso2.carbon.event.simulator.core/pom.xml
index 2b22d72fa4b..63ddf55fa07 100644
--- a/components/org.wso2.carbon.event.simulator.core/pom.xml
+++ b/components/org.wso2.carbon.event.simulator.core/pom.xml
@@ -29,7 +29,7 @@
org.wso2.carbon.event.simulator.corebundle
- WSO2 Stream Processor - Event Simulator
+ WSO2 Streaming Integrator - Event Simulatorhttp://wso2.org
diff --git a/components/org.wso2.carbon.health.check.core/pom.xml b/components/org.wso2.carbon.health.check.core/pom.xml
index 961aea624ec..f41c0b32f01 100644
--- a/components/org.wso2.carbon.health.check.core/pom.xml
+++ b/components/org.wso2.carbon.health.check.core/pom.xml
@@ -30,7 +30,7 @@
org.wso2.carbon.health.check.corebundle
- WSO2 Stream Processor - Health Check REST API
+ WSO2 Streaming Integrator - Health Check REST APIhttp://wso2.org
diff --git a/components/org.wso2.carbon.health.check.core/src/gen/java/org/wso2/carbon/health/check/core/api/HealthApi.java b/components/org.wso2.carbon.health.check.core/src/gen/java/org/wso2/carbon/health/check/core/api/HealthApi.java
index 127d85e57e9..89b707420f0 100644
--- a/components/org.wso2.carbon.health.check.core/src/gen/java/org/wso2/carbon/health/check/core/api/HealthApi.java
+++ b/components/org.wso2.carbon.health.check.core/src/gen/java/org/wso2/carbon/health/check/core/api/HealthApi.java
@@ -43,11 +43,11 @@ public class HealthApi implements Microservice {
@GET
@Produces({"application/json"})
- @io.swagger.annotations.ApiOperation(value = "Fetches the status of the Stream Processor.",
- notes = "Fetches the status of the Stream Processor. ", response = ServerStatus.class, tags = {"Artifact",})
+ @io.swagger.annotations.ApiOperation(value = "Fetches the status of the Streaming Integrator.",
+ notes = "Fetches the status of the Streaming Integrator. ", response = ServerStatus.class, tags = {"Artifact",})
@io.swagger.annotations.ApiResponses(value = {
@io.swagger.annotations.ApiResponse(code = 200,
- message = "The state of the Stream Processor is successfully retrieved.",
+ message = "The state of the Streaming Integrator is successfully retrieved.",
response = ServerStatus.class)})
public Response healthGet()
throws NotFoundException {
diff --git a/components/org.wso2.carbon.health.check.core/src/main/resources/health-check-rest-api.yaml b/components/org.wso2.carbon.health.check.core/src/main/resources/health-check-rest-api.yaml
index 6d921367d1c..0172c9ad726 100644
--- a/components/org.wso2.carbon.health.check.core/src/main/resources/health-check-rest-api.yaml
+++ b/components/org.wso2.carbon.health.check.core/src/main/resources/health-check-rest-api.yaml
@@ -3,7 +3,7 @@ info:
description: >-
This is the REST Micro Service for System Availability.
version: 1.0.0
- title: Stream Processor Health Check API
+ title: Streaming Integrator Health Check API
termsOfService: 'http://wso2.com/terms'
contact:
email: dev@wso2.org
@@ -13,7 +13,7 @@ info:
basePath: /v1.0
tags:
- name: health
- description: Everything about Stream Processor health
+ description: Everything about Streaming Integrator health
externalDocs:
description: Find out more about server health
url: 'https://docs.wso2.com/display/SP400/Key+Concepts'
@@ -27,14 +27,14 @@ paths:
x-wso2-response: 'HTTP/1.1 200 OK Content-Type: application/json {"status":"active"}'
tags:
- Artifact
- summary: Fetches the status of the Stream Processor.
+ summary: Fetches the status of the Streaming Integrator.
description: |
- Fetches the status of the Stream Processor.
+ Fetches the status of the Streaming Integrator.
produces:
- application/json
responses:
'200':
- description: The state of the Stream Processor is successfully retrieved.
+ description: The state of the Streaming Integrator is successfully retrieved.
schema:
$ref: '#/definitions/ServerStatus'
diff --git a/components/org.wso2.carbon.siddhi.editor.core/pom.xml b/components/org.wso2.carbon.siddhi.editor.core/pom.xml
index 5a15bb91ff3..4932e7fcf75 100644
--- a/components/org.wso2.carbon.siddhi.editor.core/pom.xml
+++ b/components/org.wso2.carbon.siddhi.editor.core/pom.xml
@@ -29,7 +29,7 @@
org.wso2.carbon.siddhi.editor.corebundle
- WSO2 Stream Processor - Editor Core
+ WSO2 Streaming Integrator - Editor Corehttp://wso2.org
diff --git a/components/org.wso2.carbon.siddhi.editor.core/src/main/java/org/wso2/carbon/siddhi/editor/core/internal/EditorConsoleService.java b/components/org.wso2.carbon.siddhi.editor.core/src/main/java/org/wso2/carbon/siddhi/editor/core/internal/EditorConsoleService.java
index e088f0c0dc0..01e86d244e5 100644
--- a/components/org.wso2.carbon.siddhi.editor.core/src/main/java/org/wso2/carbon/siddhi/editor/core/internal/EditorConsoleService.java
+++ b/components/org.wso2.carbon.siddhi.editor.core/src/main/java/org/wso2/carbon/siddhi/editor/core/internal/EditorConsoleService.java
@@ -72,7 +72,7 @@ public void onOpen(WebSocketConnection webSocketConnection) {
@OnMessage
public void onMessage(String text, WebSocketConnection webSocketConnection) {
- webSocketConnection.pushText("Welcome to Stream Processor Studio");
+ webSocketConnection.pushText("Welcome to Streaming Integrator Tooling");
LOGGER.info("Received message : " + text);
}
diff --git a/components/org.wso2.carbon.siddhi.editor.core/src/main/java/org/wso2/carbon/siddhi/editor/core/internal/EditorMicroservice.java b/components/org.wso2.carbon.siddhi.editor.core/src/main/java/org/wso2/carbon/siddhi/editor/core/internal/EditorMicroservice.java
index c447617876f..71477e6c14f 100644
--- a/components/org.wso2.carbon.siddhi.editor.core/src/main/java/org/wso2/carbon/siddhi/editor/core/internal/EditorMicroservice.java
+++ b/components/org.wso2.carbon.siddhi.editor.core/src/main/java/org/wso2/carbon/siddhi/editor/core/internal/EditorMicroservice.java
@@ -1082,7 +1082,7 @@ public Response getDefaultSampleStreamEvent(@PathParam("appName") String appName
*/
@Activate
protected void start(BundleContext bundleContext) throws Exception {
- // Create Stream Processor Service
+ // Create Streaming Integrator Service
EditorDataHolder.setDebugProcessorService(new DebugProcessorService());
SiddhiManager siddhiManager = new SiddhiManager();
FileConfigManager fileConfigManager = new FileConfigManager(configProvider);
diff --git a/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/index.html b/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/index.html
index 14f5620499e..26784db0490 100644
--- a/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/index.html
+++ b/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/index.html
@@ -379,7 +379,7 @@
Warning!
-
Stream Processor Configuration Wizard
+
Streaming Integrator Configuration Wizard
@@ -2176,7 +2176,7 @@
Export as
-
Welcome to the Stream Processor Studio Tour Guide
+
Welcome to the Streaming Integrator Studio Tour Guide
diff --git a/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/js/guide/guide.js b/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/js/guide/guide.js
index aee0437afd8..8ce15ec42e9 100644
--- a/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/js/guide/guide.js
+++ b/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/js/guide/guide.js
@@ -43,7 +43,7 @@ define(['jquery', 'lodash', 'log', 'enjoyhint', 'designViewUtils', 'workspace',
//Script array for the complete guide
this.completeGuide = [
{
- 'click #newButton': 'Welcome to WSO2 Stream Processor Studio! Click New to get started.',
+ 'click #newButton': 'Welcome to WSO2 Streaming Integrator Studio! Click New to get started.',
'showNext' : false
},
{
diff --git a/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/js/source-editor/constants.js b/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/js/source-editor/constants.js
index 9dd548423f6..67eb60ba05d 100644
--- a/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/js/source-editor/constants.js
+++ b/components/org.wso2.carbon.siddhi.editor.core/src/main/resources/web/js/source-editor/constants.js
@@ -67,7 +67,7 @@ define(function() {
*/
constants.typeToDisplayNameMap = {};
constants.typeToDisplayNameMap[constants.FUNCTIONS] = "Function";
- constants.typeToDisplayNameMap[constants.STREAM_PROCESSORS] = "Stream Processor";
+ constants.typeToDisplayNameMap[constants.STREAM_PROCESSORS] = "Streaming Integrator";
constants.typeToDisplayNameMap[constants.WINDOW_PROCESSORS] = "Window Processor";
constants.typeToDisplayNameMap[constants.STREAMS] = "Stream";
constants.typeToDisplayNameMap[constants.INNER_STREAMS] = "Inner Stream";
diff --git a/components/org.wso2.carbon.siddhi.store.api.rest/pom.xml b/components/org.wso2.carbon.siddhi.store.api.rest/pom.xml
index f3b8109a50e..66f5a0dbb79 100644
--- a/components/org.wso2.carbon.siddhi.store.api.rest/pom.xml
+++ b/components/org.wso2.carbon.siddhi.store.api.rest/pom.xml
@@ -30,7 +30,7 @@
org.wso2.carbon.siddhi.store.api.restbundle
- WSO2 Stream Processor - Siddhi Store Query REST API
+ WSO2 Streaming Integrator - Siddhi Store Query REST APIhttp://wso2.org
diff --git a/components/org.wso2.carbon.streaming.integrator.common/pom.xml b/components/org.wso2.carbon.streaming.integrator.common/pom.xml
index 8a3074f35bd..b5262055938 100644
--- a/components/org.wso2.carbon.streaming.integrator.common/pom.xml
+++ b/components/org.wso2.carbon.streaming.integrator.common/pom.xml
@@ -29,7 +29,7 @@
org.wso2.carbon.streaming.integrator.commonbundle
- WSO2 Stream Processor - Common
+ WSO2 Streaming Integrator - Commonhttp://wso2.org
diff --git a/components/org.wso2.carbon.streaming.integrator.common/src/main/java/org/wso2/carbon/streaming/integrator/common/utils/SPConstants.java b/components/org.wso2.carbon.streaming.integrator.common/src/main/java/org/wso2/carbon/streaming/integrator/common/utils/SPConstants.java
index 89af387f761..1d89eba79c2 100644
--- a/components/org.wso2.carbon.streaming.integrator.common/src/main/java/org/wso2/carbon/streaming/integrator/common/utils/SPConstants.java
+++ b/components/org.wso2.carbon.streaming.integrator.common/src/main/java/org/wso2/carbon/streaming/integrator/common/utils/SPConstants.java
@@ -18,7 +18,7 @@
package org.wso2.carbon.streaming.integrator.common.utils;
/**
- * Stream Processor Constants.
+ * Streaming Integrator Constants.
*/
public class SPConstants {
public static final String WSO2_SP_TOKEN_2 = "HID";
diff --git a/components/org.wso2.carbon.streaming.integrator.core/pom.xml b/components/org.wso2.carbon.streaming.integrator.core/pom.xml
index d78aaf508b8..48b5c46a145 100644
--- a/components/org.wso2.carbon.streaming.integrator.core/pom.xml
+++ b/components/org.wso2.carbon.streaming.integrator.core/pom.xml
@@ -29,7 +29,7 @@
org.wso2.carbon.streaming.integrator.corebundle
- WSO2 Stream Processor - Core
+ WSO2 Streaming Integrator - Corehttp://wso2.org
diff --git a/components/org.wso2.carbon.streaming.integrator.core/src/main/java/org/wso2/carbon/streaming/integrator/core/internal/StreamProcessorDeployer.java b/components/org.wso2.carbon.streaming.integrator.core/src/main/java/org/wso2/carbon/streaming/integrator/core/internal/StreamProcessorDeployer.java
index 20800fa28fd..d261d874c62 100644
--- a/components/org.wso2.carbon.streaming.integrator.core/src/main/java/org/wso2/carbon/streaming/integrator/core/internal/StreamProcessorDeployer.java
+++ b/components/org.wso2.carbon.streaming.integrator.core/src/main/java/org/wso2/carbon/streaming/integrator/core/internal/StreamProcessorDeployer.java
@@ -316,7 +316,7 @@ public void init() {
try {
directoryLocation = new URL("file:" + SiddhiAppProcessorConstants.SIDDHI_APP_FILES_DIRECTORY);
setServerType();
- log.debug("Stream Processor Deployer initiated.");
+ log.debug("Streaming Integrator Deployer initiated.");
} catch (MalformedURLException e) {
log.error("Error while initializing directoryLocation" + SiddhiAppProcessorConstants.
SIDDHI_APP_FILES_DIRECTORY, e);
diff --git a/components/org.wso2.carbon.streaming.integrator.core/src/main/resources/exposeSystemVariable.yaml b/components/org.wso2.carbon.streaming.integrator.core/src/main/resources/exposeSystemVariable.yaml
index 568b4882906..c9dbb2b84c0 100644
--- a/components/org.wso2.carbon.streaming.integrator.core/src/main/resources/exposeSystemVariable.yaml
+++ b/components/org.wso2.carbon.streaming.integrator.core/src/main/resources/exposeSystemVariable.yaml
@@ -1,7 +1,7 @@
swagger: '2.0'
info:
version: 1.0.0
- title: Exposing System Run Time of Stream Processor
+ title: Exposing System Run Time of Streaming Integrator
description: >-
This provides information about the runtime of the stream processor.
contact:
diff --git a/components/org.wso2.carbon.streaming.integrator.statistics/src/main/resources/staticstics-api.yaml b/components/org.wso2.carbon.streaming.integrator.statistics/src/main/resources/staticstics-api.yaml
index a54864b7981..76b15f95086 100644
--- a/components/org.wso2.carbon.streaming.integrator.statistics/src/main/resources/staticstics-api.yaml
+++ b/components/org.wso2.carbon.streaming.integrator.statistics/src/main/resources/staticstics-api.yaml
@@ -20,7 +20,7 @@
swagger: '2.0'
info:
version: 1.0.0
- title: Stream Processor Status Dashboard Service
+ title: Streaming Integrator Status Dashboard Service
description: >-
This provides information about the REST APIs available for WSO2 Steam
Processor Status Dashboard from SP worker.
diff --git a/components/org.wso2.carbon.streaming.integrator.statistics/src/main/resources/system-details-api.yaml b/components/org.wso2.carbon.streaming.integrator.statistics/src/main/resources/system-details-api.yaml
index 61edeaa2a9d..3a907de86e4 100644
--- a/components/org.wso2.carbon.streaming.integrator.statistics/src/main/resources/system-details-api.yaml
+++ b/components/org.wso2.carbon.streaming.integrator.statistics/src/main/resources/system-details-api.yaml
@@ -20,7 +20,7 @@
swagger: '2.0'
info:
version: 1.0.0
- title: Stream Processor Status Dashboard Service
+ title: Streaming Integrator Status Dashboard Service
description: >-
This provides information about the REST API available for getting general details of a SP node.
contact:
diff --git a/components/si-distribution/carbon-home/bin/version.txt b/components/si-distribution/carbon-home/bin/version.txt
index 99e46d8fb37..fb17ff13327 100644
--- a/components/si-distribution/carbon-home/bin/version.txt
+++ b/components/si-distribution/carbon-home/bin/version.txt
@@ -1 +1 @@
-WSO2 Stream Processor v${project.version}
+WSO2 Streaming Integrator v${project.version}
diff --git a/components/si-distribution/carbon-home/conf/server/deployment.yaml b/components/si-distribution/carbon-home/conf/server/deployment.yaml
index c327382201a..a21c43cbf09 100644
--- a/components/si-distribution/carbon-home/conf/server/deployment.yaml
+++ b/components/si-distribution/carbon-home/conf/server/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/si-distribution/carbon-home/samples/artifacts/1001/ReceiveAndCount.siddhi b/components/si-distribution/carbon-home/samples/artifacts/1001/ReceiveAndCount.siddhi
index b6e67159e18..5e6113198c0 100644
--- a/components/si-distribution/carbon-home/samples/artifacts/1001/ReceiveAndCount.siddhi
+++ b/components/si-distribution/carbon-home/samples/artifacts/1001/ReceiveAndCount.siddhi
@@ -5,7 +5,7 @@
/*
Purpose:
- This application demonstrates how to configure WSO2 Stream Processor to receive events via HTTP transport and view the output on the console. The count of all events arriving to the stream is calculated.
+ This application demonstrates how to configure WSO2 Streaming Integrator to receive events via HTTP transport and view the output on the console. The count of all events arriving to the stream is calculated.
Prerequisites:
1) Save this sample
diff --git a/components/si-distribution/pom.xml b/components/si-distribution/pom.xml
index 8575d5b5b0d..fa389a4400c 100644
--- a/components/si-distribution/pom.xml
+++ b/components/si-distribution/pom.xml
@@ -137,7 +137,7 @@
zip
-
+
org.wso2.carbon.analyticsorg.wso2.carbon.streaming.integrator.core.feature
@@ -458,7 +458,7 @@
${carbon.deployment.version}
-
+
org.wso2.carbon.streaming.integrator.core.feature${carbon.analytics.version}
@@ -675,7 +675,7 @@
${msf4j.version}
-
+
org.wso2.carbon.streaming.integrator.core.feature${carbon.analytics.version}
diff --git a/components/si-tooling-distribution/carbon-home/bin/version.txt b/components/si-tooling-distribution/carbon-home/bin/version.txt
index 99e46d8fb37..fb17ff13327 100644
--- a/components/si-tooling-distribution/carbon-home/bin/version.txt
+++ b/components/si-tooling-distribution/carbon-home/bin/version.txt
@@ -1 +1 @@
-WSO2 Stream Processor v${project.version}
+WSO2 Streaming Integrator v${project.version}
diff --git a/components/si-tooling-distribution/carbon-home/conf/server/deployment.yaml b/components/si-tooling-distribution/carbon-home/conf/server/deployment.yaml
index 674f62470dd..ee91e4c15f2 100644
--- a/components/si-tooling-distribution/carbon-home/conf/server/deployment.yaml
+++ b/components/si-tooling-distribution/carbon-home/conf/server/deployment.yaml
@@ -19,7 +19,7 @@ wso2.carbon:
# value to uniquely identify a server
id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/si-tooling-distribution/carbon-home/samples/artifacts/1001/ReceiveAndCount.siddhi b/components/si-tooling-distribution/carbon-home/samples/artifacts/1001/ReceiveAndCount.siddhi
index b6e67159e18..5e6113198c0 100644
--- a/components/si-tooling-distribution/carbon-home/samples/artifacts/1001/ReceiveAndCount.siddhi
+++ b/components/si-tooling-distribution/carbon-home/samples/artifacts/1001/ReceiveAndCount.siddhi
@@ -5,7 +5,7 @@
/*
Purpose:
- This application demonstrates how to configure WSO2 Stream Processor to receive events via HTTP transport and view the output on the console. The count of all events arriving to the stream is calculated.
+ This application demonstrates how to configure WSO2 Streaming Integrator to receive events via HTTP transport and view the output on the console. The count of all events arriving to the stream is calculated.
Prerequisites:
1) Save this sample
diff --git a/components/si-tooling-distribution/pom.xml b/components/si-tooling-distribution/pom.xml
index b1fee196c78..92a056778f4 100644
--- a/components/si-tooling-distribution/pom.xml
+++ b/components/si-tooling-distribution/pom.xml
@@ -143,7 +143,7 @@
zip
-
+
org.wso2.carbon.analyticsorg.wso2.carbon.streaming.integrator.core.feature
@@ -524,7 +524,7 @@
${carbon.deployment.version}
-
+
org.wso2.carbon.streaming.integrator.core.feature${carbon.analytics.version}
diff --git a/components/si-tooling-distribution/src/assembly/bin.xml b/components/si-tooling-distribution/src/assembly/bin.xml
index 12c4981577b..cc1e2d2d620 100644
--- a/components/si-tooling-distribution/src/assembly/bin.xml
+++ b/components/si-tooling-distribution/src/assembly/bin.xml
@@ -18,7 +18,7 @@
truewso2-streaming-integrator-tooling-${project.version}
- WSO2 Stream Processor Distribution
+ WSO2 Streaming Integrator Distributionzip
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/configuration/deployment.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/configuration/deployment.yaml
index 4b2354d7950..ea61226ca55 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/configuration/deployment.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/configuration/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/deployment.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/deployment.yaml
index c265d7e0e62..55c012297d2 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/deployment.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/deployment.yaml
@@ -16,9 +16,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/distributed/manager/deployment.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/distributed/manager/deployment.yaml
index fe0c192b1a9..9bfb5ef56c5 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/distributed/manager/deployment.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/distributed/manager/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/distributed/resource/deployment.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/distributed/resource/deployment.yaml
index c4a133f55d3..1a8966617bd 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/distributed/resource/deployment.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/distributed/resource/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/ha/deployment.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/ha/deployment.yaml
index 3025d4c381a..36353f1aea0 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/ha/deployment.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/ha/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/metrics/deployment.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/metrics/deployment.yaml
index 23fb74a089e..71acf6f7f7b 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/metrics/deployment.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/metrics/deployment.yaml
@@ -19,7 +19,7 @@ wso2.carbon:
# value to uniquely identify a server
id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/db/deployment-structure.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/db/deployment-structure.yaml
index 766731c711c..9715f855abd 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/db/deployment-structure.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/db/deployment-structure.yaml
@@ -19,7 +19,7 @@ wso2.carbon:
# value to uniquely identify a server
id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/db/deployment.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/db/deployment.yaml
index dcdb57dfba0..fed0e6d0a81 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/db/deployment.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/db/deployment.yaml
@@ -19,7 +19,7 @@ wso2.carbon:
# value to uniquely identify a server
id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/file/configTest/deployment.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/file/configTest/deployment.yaml
index d8cc39bd838..029bf9fd197 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/file/configTest/deployment.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/file/configTest/deployment.yaml
@@ -19,7 +19,7 @@ wso2.carbon:
# value to uniquely identify a server
id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/file/default/deployment.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/file/default/deployment.yaml
index ed66f81d9ea..41fc3f832a6 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/file/default/deployment.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/file/default/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment-structure.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment-structure.yaml
index 29a719b90d4..8890af0d492 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment-structure.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment-structure.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment.yaml
index 08a37226d9c..6c456065b81 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-file/default/deployment.yaml b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-file/default/deployment.yaml
index 878264ab3e6..70d3cc59b6d 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-file/default/deployment.yaml
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/conf/persistence/incremental-file/default/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/streaming-integrator-osgi-tests/src/test/resources/editor/samples/ReceiveAndCount.siddhi b/components/streaming-integrator-osgi-tests/src/test/resources/editor/samples/ReceiveAndCount.siddhi
index b6e67159e18..5e6113198c0 100644
--- a/components/streaming-integrator-osgi-tests/src/test/resources/editor/samples/ReceiveAndCount.siddhi
+++ b/components/streaming-integrator-osgi-tests/src/test/resources/editor/samples/ReceiveAndCount.siddhi
@@ -5,7 +5,7 @@
/*
Purpose:
- This application demonstrates how to configure WSO2 Stream Processor to receive events via HTTP transport and view the output on the console. The count of all events arriving to the stream is calculated.
+ This application demonstrates how to configure WSO2 Streaming Integrator to receive events via HTTP transport and view the output on the console. The count of all events arriving to the stream is calculated.
Prerequisites:
1) Save this sample
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/configuration/deployment.yaml b/components/tooling-osgi-tests/src/test/resources/conf/configuration/deployment.yaml
index e5ff9ab8021..4f90a97033b 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/configuration/deployment.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/configuration/deployment.yaml
@@ -19,7 +19,7 @@ wso2.carbon:
# value to uniquely identify a server
id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/deployment.yaml b/components/tooling-osgi-tests/src/test/resources/conf/deployment.yaml
index 27373086a4d..97fa6100147 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/deployment.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/deployment.yaml
@@ -18,7 +18,7 @@ wso2.carbon:
# value to uniquely identify a server
id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/distributed/manager/deployment.yaml b/components/tooling-osgi-tests/src/test/resources/conf/distributed/manager/deployment.yaml
index fe0c192b1a9..9bfb5ef56c5 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/distributed/manager/deployment.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/distributed/manager/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/distributed/resource/deployment.yaml b/components/tooling-osgi-tests/src/test/resources/conf/distributed/resource/deployment.yaml
index c4a133f55d3..1a8966617bd 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/distributed/resource/deployment.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/distributed/resource/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/ha/deployment.yaml b/components/tooling-osgi-tests/src/test/resources/conf/ha/deployment.yaml
index 3025d4c381a..36353f1aea0 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/ha/deployment.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/ha/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/metrics/deployment.yaml b/components/tooling-osgi-tests/src/test/resources/conf/metrics/deployment.yaml
index 66747c7ae7a..6ecd4b183ef 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/metrics/deployment.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/metrics/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/persistence/db/deployment-structure.yaml b/components/tooling-osgi-tests/src/test/resources/conf/persistence/db/deployment-structure.yaml
index 55e95867d7e..9715f855abd 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/persistence/db/deployment-structure.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/persistence/db/deployment-structure.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/persistence/db/deployment.yaml b/components/tooling-osgi-tests/src/test/resources/conf/persistence/db/deployment.yaml
index 66689e811dd..fed0e6d0a81 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/persistence/db/deployment.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/persistence/db/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/persistence/file/configTest/deployment.yaml b/components/tooling-osgi-tests/src/test/resources/conf/persistence/file/configTest/deployment.yaml
index 5265353bc55..029bf9fd197 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/persistence/file/configTest/deployment.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/persistence/file/configTest/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/persistence/file/default/deployment.yaml b/components/tooling-osgi-tests/src/test/resources/conf/persistence/file/default/deployment.yaml
index ed66f81d9ea..41fc3f832a6 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/persistence/file/default/deployment.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/persistence/file/default/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment-structure.yaml b/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment-structure.yaml
index 29a719b90d4..8890af0d492 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment-structure.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment-structure.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment.yaml b/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment.yaml
index 08a37226d9c..6c456065b81 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-db/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-file/default/deployment.yaml b/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-file/default/deployment.yaml
index 878264ab3e6..70d3cc59b6d 100644
--- a/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-file/default/deployment.yaml
+++ b/components/tooling-osgi-tests/src/test/resources/conf/persistence/incremental-file/default/deployment.yaml
@@ -17,9 +17,9 @@
# Carbon Configuration Parameters
wso2.carbon:
# value to uniquely identify a server
- id: wso2-sp
+ id: wso2-si
# server name
- name: WSO2 Stream Processor
+ name: WSO2 Streaming Integrator
# ports used by this server
ports:
# port offset
diff --git a/components/tooling-osgi-tests/src/test/resources/server/samples/ReceiveAndCount.siddhi b/components/tooling-osgi-tests/src/test/resources/server/samples/ReceiveAndCount.siddhi
index b6e67159e18..5e6113198c0 100644
--- a/components/tooling-osgi-tests/src/test/resources/server/samples/ReceiveAndCount.siddhi
+++ b/components/tooling-osgi-tests/src/test/resources/server/samples/ReceiveAndCount.siddhi
@@ -5,7 +5,7 @@
/*
Purpose:
- This application demonstrates how to configure WSO2 Stream Processor to receive events via HTTP transport and view the output on the console. The count of all events arriving to the stream is calculated.
+ This application demonstrates how to configure WSO2 Streaming Integrator to receive events via HTTP transport and view the output on the console. The count of all events arriving to the stream is calculated.
Prerequisites:
1) Save this sample
diff --git a/features/org.wso2.carbon.analytics.auth.rest.api.feature/pom.xml b/features/org.wso2.carbon.analytics.auth.rest.api.feature/pom.xml
index a7b3b49a81d..0719f40bf44 100644
--- a/features/org.wso2.carbon.analytics.auth.rest.api.feature/pom.xml
+++ b/features/org.wso2.carbon.analytics.auth.rest.api.feature/pom.xml
@@ -28,7 +28,7 @@
org.wso2.carbon.analytics.auth.rest.api.featurecarbon-feature
- WSO2 Stream Processor - Authentication API Feature
+ WSO2 Streaming Integrator - Authentication API Featurehttp://wso2.org
diff --git a/features/org.wso2.carbon.analytics.msf4j.interceptor.common.feature/pom.xml b/features/org.wso2.carbon.analytics.msf4j.interceptor.common.feature/pom.xml
index 9c34e5965fd..18f6c81901a 100644
--- a/features/org.wso2.carbon.analytics.msf4j.interceptor.common.feature/pom.xml
+++ b/features/org.wso2.carbon.analytics.msf4j.interceptor.common.feature/pom.xml
@@ -28,7 +28,7 @@
org.wso2.carbon.analytics.msf4j.interceptor.common.featurecarbon-feature
- WSO2 Stream Processor - Interceptor Feature
+ WSO2 Streaming Integrator - Interceptor Featurehttp://wso2.orgThis feature contains the bundles related to Micro services Interceptor
diff --git a/features/org.wso2.carbon.business.rules.core.feature/pom.xml b/features/org.wso2.carbon.business.rules.core.feature/pom.xml
index 89e7cb2bf5f..55283c91d64 100644
--- a/features/org.wso2.carbon.business.rules.core.feature/pom.xml
+++ b/features/org.wso2.carbon.business.rules.core.feature/pom.xml
@@ -28,7 +28,7 @@
org.wso2.carbon.business.rules.core.featurecarbon-feature
- WSO2 Stream Processor - Business Rules Core Feature
+ WSO2 Streaming Integrator - Business Rules Core Featurehttp://wso2.orgThis feature contains the bundles related to business rules
diff --git a/features/org.wso2.carbon.business.rules.templates.editor.core.feature/pom.xml b/features/org.wso2.carbon.business.rules.templates.editor.core.feature/pom.xml
index aa1c27f0604..05d5ab068af 100644
--- a/features/org.wso2.carbon.business.rules.templates.editor.core.feature/pom.xml
+++ b/features/org.wso2.carbon.business.rules.templates.editor.core.feature/pom.xml
@@ -28,7 +28,7 @@
org.wso2.carbon.business.rules.templates.editor.core.featurecarbon-feature
- WSO2 Stream Processor - Business Rules Template Editor Feature
+ WSO2 Streaming Integrator - Business Rules Template Editor Featurehttp://wso2.orgThis feature contains the bundles related to Business Rules Template Editor
diff --git a/features/org.wso2.carbon.business.rules.web.feature/pom.xml b/features/org.wso2.carbon.business.rules.web.feature/pom.xml
index ef254449740..8cb67add84f 100644
--- a/features/org.wso2.carbon.business.rules.web.feature/pom.xml
+++ b/features/org.wso2.carbon.business.rules.web.feature/pom.xml
@@ -27,7 +27,7 @@
4.0.0org.wso2.carbon.business.rules.web.featurepom
- WSO2 Stream Processor Business Rule Web Component
+ WSO2 Streaming Integrator Business Rule Web Componenthttp://wso2.org
diff --git a/features/org.wso2.carbon.event.simulator.core.feature/pom.xml b/features/org.wso2.carbon.event.simulator.core.feature/pom.xml
index c4a8062cb15..3d2a0614baf 100644
--- a/features/org.wso2.carbon.event.simulator.core.feature/pom.xml
+++ b/features/org.wso2.carbon.event.simulator.core.feature/pom.xml
@@ -28,7 +28,7 @@
org.wso2.carbon.event.simulator.core.featurecarbon-feature
- WSO2 Stream Processor - Event Simulator Feature
+ WSO2 Streaming Integrator - Event Simulator Featurehttp://wso2.orgThis feature contains the bundles related to Event Simulator
diff --git a/features/org.wso2.carbon.health.check.core.feature/pom.xml b/features/org.wso2.carbon.health.check.core.feature/pom.xml
index 5e0349db05a..0793a9dcc42 100644
--- a/features/org.wso2.carbon.health.check.core.feature/pom.xml
+++ b/features/org.wso2.carbon.health.check.core.feature/pom.xml
@@ -28,7 +28,7 @@
org.wso2.carbon.health.check.core.featurecarbon-feature
- WSO2 Stream Processor - Heath Check Core API Feature
+ WSO2 Streaming Integrator - Heath Check Core API Featurehttp://wso2.orgThis feature contains the bundles related to Health Check API
diff --git a/features/org.wso2.carbon.siddhi.editor.core.feature/pom.xml b/features/org.wso2.carbon.siddhi.editor.core.feature/pom.xml
index afdc354ebe4..27b181da9cd 100644
--- a/features/org.wso2.carbon.siddhi.editor.core.feature/pom.xml
+++ b/features/org.wso2.carbon.siddhi.editor.core.feature/pom.xml
@@ -28,7 +28,7 @@
org.wso2.carbon.siddhi.editor.core.featurecarbon-feature
- WSO2 Stream Processor - Siddhi Editor Feature
+ WSO2 Streaming Integrator - Siddhi Editor Featurehttp://wso2.orgThis feature contains the bundles related to Siddhi Edior
diff --git a/features/org.wso2.carbon.siddhi.editor.core.feature/src/main/resources/docker-export/README.md b/features/org.wso2.carbon.siddhi.editor.core.feature/src/main/resources/docker-export/README.md
index c95a8e5d47f..ba41297a4fc 100644
--- a/features/org.wso2.carbon.siddhi.editor.core.feature/src/main/resources/docker-export/README.md
+++ b/features/org.wso2.carbon.siddhi.editor.core.feature/src/main/resources/docker-export/README.md
@@ -1,10 +1,10 @@
-# WSO2 Stream Processor Studio Docker Artifacts
+# WSO2 Streaming Integrator Studio Docker Artifacts
-Docker artifacts in WSO2 Stream Processor Studio can be used to build Docker containers with Siddhi files.
+Docker artifacts in WSO2 Streaming Integrator Studio can be used to build Docker containers with Siddhi files.
## Directory Structure
-In WSO2 Stream Processor Studio, Docker artifacts can be created for either **Editor** profile or **Worker** profile. Directory structure of the ZIP file is as follows.
+In WSO2 Streaming Integrator Studio, Docker artifacts can be created for either **Editor** profile or **Worker** profile. Directory structure of the ZIP file is as follows.
```
.
diff --git a/features/org.wso2.carbon.siddhi.store.api.rest.feature/pom.xml b/features/org.wso2.carbon.siddhi.store.api.rest.feature/pom.xml
index b65e08afc4e..01b3cf9ddc8 100644
--- a/features/org.wso2.carbon.siddhi.store.api.rest.feature/pom.xml
+++ b/features/org.wso2.carbon.siddhi.store.api.rest.feature/pom.xml
@@ -28,7 +28,7 @@
org.wso2.carbon.siddhi.store.api.rest.featurecarbon-feature
- WSO2 Stream Processor - Siddhi Store Query REST API Feature
+ WSO2 Streaming Integrator - Siddhi Store Query REST API Featurehttp://wso2.orgThis feature contains the bundles related to Siddhi Store REST API
diff --git a/features/org.wso2.carbon.streaming.integrator.common.feature/pom.xml b/features/org.wso2.carbon.streaming.integrator.common.feature/pom.xml
index 497d6800e8a..db3688b1c3d 100644
--- a/features/org.wso2.carbon.streaming.integrator.common.feature/pom.xml
+++ b/features/org.wso2.carbon.streaming.integrator.common.feature/pom.xml
@@ -28,9 +28,9 @@
4.0.0org.wso2.carbon.streaming.integrator.common.featurecarbon-feature
- WSO2 Stream Processor - Common Feature
+ WSO2 Streaming Integrator - Common Featurehttp://wso2.org
- This feature contains the bundles related to Stream Processor Common
+ This feature contains the bundles related to Streaming Integrator Common
diff --git a/features/org.wso2.carbon.streaming.integrator.core.feature/pom.xml b/features/org.wso2.carbon.streaming.integrator.core.feature/pom.xml
index aad4a244c85..758763add13 100644
--- a/features/org.wso2.carbon.streaming.integrator.core.feature/pom.xml
+++ b/features/org.wso2.carbon.streaming.integrator.core.feature/pom.xml
@@ -28,9 +28,9 @@
org.wso2.carbon.streaming.integrator.core.featurecarbon-feature
- WSO2 Stream Processor - Core Feature
+ WSO2 Streaming Integrator - Core Featurehttp://wso2.org
- This feature contains the bundles related to Stream Processor Core
+ This feature contains the bundles related to Streaming Integrator Core
diff --git a/features/org.wso2.carbon.streaming.integrator.statistics.feature/pom.xml b/features/org.wso2.carbon.streaming.integrator.statistics.feature/pom.xml
index c30cb4b0384..a35290400ea 100644
--- a/features/org.wso2.carbon.streaming.integrator.statistics.feature/pom.xml
+++ b/features/org.wso2.carbon.streaming.integrator.statistics.feature/pom.xml
@@ -28,9 +28,9 @@
org.wso2.carbon.streaming.integrator.statistics.featurecarbon-feature
- WSO2 Stream Processor - Statistics Feature
+ WSO2 Streaming Integrator - Statistics Featurehttp://wso2.org
- This feature contains the bundles related to Stream Processor Core
+ This feature contains the bundles related to Streaming Integrator Core
diff --git a/features/org.wso2.siddhi.feature/pom.xml b/features/org.wso2.siddhi.feature/pom.xml
index d299469f16f..7b7512ba100 100644
--- a/features/org.wso2.siddhi.feature/pom.xml
+++ b/features/org.wso2.siddhi.feature/pom.xml
@@ -28,7 +28,7 @@
org.wso2.siddhi.featurecarbon-feature
- WSO2 Stream Processor - Siddhi Feature
+ WSO2 Streaming Integrator - Siddhi Featurehttp://wso2.orgThis feature contains the dependency bundles related to Siddhi Core
diff --git a/components/org.wso2.carbon.streaming.integrator.core/src/main/java/org/wso2/carbon/streaming/integrator/core/internal/ServiceComponent.java b/components/org.wso2.carbon.streaming.integrator.core/src/main/java/org/wso2/carbon/streaming/integrator/core/internal/ServiceComponent.java
index 0a79f14b871..ca1cd668479 100644
--- a/components/org.wso2.carbon.streaming.integrator.core/src/main/java/org/wso2/carbon/streaming/integrator/core/internal/ServiceComponent.java
+++ b/components/org.wso2.carbon.streaming.integrator.core/src/main/java/org/wso2/carbon/streaming/integrator/core/internal/ServiceComponent.java
@@ -99,7 +99,7 @@ protected void start(BundleContext bundleContext) throws Exception {
String siddhiAppsReference = System.getProperty(SiddhiAppProcessorConstants.SYSTEM_PROP_RUN_SIDDHI_APPS);
ConfigProvider configProvider = StreamProcessorDataHolder.getInstance().getConfigProvider();
// Create Stream Processor Service
StreamProcessorDataHolder.setStreamProcessorService(new StreamProcessorService());
SiddhiManager siddhiManager = new SiddhiManager();
FileConfigManager fileConfigManager = new FileConfigManager(configProvider);
@@ -361,7 +361,7 @@ private void setUpClustering(ClusterCoordinator clusterCoordinator) throws Confi
throw new HAModeException("More than two nodes can not be used in the minimum HA mode. " +
"Use another clustering mode, change the groupId or disable clustering.");
}
- log.info("WSO2 Stream Processor Starting in Two Node Minimum HA Deployment");
+ log.info("WSO2 Streaming Integrator Starting in Two Node Minimum HA Deployment");
StreamProcessorDataHolder.setIsStatisticsEnabled(
SPMetricsDataHolder.getInstance().getMetricManagementService().isEnabled());
StatisticsManager statisticsManager = StreamProcessorDataHolder.getStatisticsConfiguration().
@@ -99,7 +99,7 @@ protected void start(BundleContext bundleContext) throws Exception {
String siddhiAppsReference = System.getProperty(SiddhiAppProcessorConstants.SYSTEM_PROP_RUN_SIDDHI_APPS);
ConfigProvider configProvider = StreamProcessorDataHolder.getInstance().getConfigProvider();
- // Create Stream Processor Service
+ // Create Streaming Integrator Service
StreamProcessorDataHolder.setStreamProcessorService(new StreamProcessorService());
SiddhiManager siddhiManager = new SiddhiManager();